@@ -2,7 +2,7 @@ import { Exception } from './exceptions'
 
 let Selectors = {}
 Selectors = {
-  init ({ store }) { // TODO: avoid init method
+  init ({ store }) {
     Selectors.store = store
   },
   // --- config --
@@ -20,6 +20,13 @@ Selectors = {
   getVmDisks ({ vmId }) {
     return getState().vms.getIn(['vms', vmId, 'disks'])
   },
+  getOperatingSystemByName (name) {
+    return getState().operatingSystems.get('operatingSystems').toList().find(os =>
+      os.get('name') === name)
+  },
+  getFilter () {
+    return getState().config.get('filter')
+  },
 }
 
 function getState () {
